.. cz-benchmarks documentation master file, created by
   sphinx-quickstart on Wed Mar 19 11:27:15 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

cz-benchmarks Documentation
===========================

What is cz-benchmarks?
=======================

cz-benchmarks is a package for standardized evaluation and comparison of machine learning models for biological applications (first, in the single-cell transcriptomics domain, with future plans to expand to additional domains). The package provides a toolkit for running containerized models, executing biologically-relevant tasks, and computing performance metrics. We see this tool as a step towards ensuring that large-scale ML Models can be harnessed to deliver genuine biological insights -- by building trust, accelerating development, and bridging the gap between ML and biology communities.

Why benchmarking? Why now?
==========================

Last year, CZI hosted a workshop focused on benchmarking and evaluation of ML Models in biology, and the `insights gained <https://virtualcellmodels.cziscience.com/micro-pub/benchmarking-workshop>`_ have reinforced our commitment to supporting the development of a robust benchmarking infrastructure, which we see as critical to achieving our Virtual Cell vision.

💬 Community Feedback & Contributions
======================================

CZI welcome your feedback and contributions as we continue to improve the package. If you encounter any issues or have suggestions, please `open an issue <https://github.com/chanzuckerberg/cz-benchmarks/issues>`_ on GitHub or reach out to us at `virtualcellmodels@chanzuckerberg.com <mailto:virtualcellmodels@chanzuckerberg.com>`_.

You can find **cz-benchmarks** on:

- `PyPI <https://pypi.org/project/cz-benchmarks/>`_ – for installation and release information.
- `GitHub <https://github.com/chanzuckerberg/cz-benchmarks>`_ – for source code, issue tracking, and contributions.


.. toctree::
   :maxdepth: 1

   quick_start
   benchmarking_philosophy
   how_to_guides/index
   notebook_examples
   developer_guides/index
   api_reference
   assets
   policy/index
   roadmap
   legal
   changelog_release_notes

